pub struct ArgumentsCollectRequest {
pub prefix: String,
}Fields
prefix: StringTrait Implementations
Sourceimpl Clone for ArgumentsCollectRequest
impl Clone for ArgumentsCollectRequest
Sourcefn clone(&self) -> ArgumentsCollectRequest
fn clone(&self) -> ArgumentsCollectRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsCollectRequest
impl Debug for ArgumentsCollectRequest
Sourceimpl<___E> Encode<ArgumentsCollectRequest<'static>, ___E> for ArgumentsCollectRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ArgumentsCollectRequest<'static>, ___E> for ArgumentsCollectRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsCollectRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsCollectRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsCollectRequest<'static>, ___E> for &'a ArgumentsCollectRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ArgumentsCollectRequest<'static>, ___E> for &'a ArgumentsCollectRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsCollectRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsCollectRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsCollectRequest<'static>>, ___E> for ArgumentsCollectRequestwhere
___E: Encoder + ?Sized,
ArgumentsCollectRequest: Encode<ArgumentsCollectRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsCollectRequest<'static>>, ___E> for ArgumentsCollectRequestwhere
___E: Encoder + ?Sized,
ArgumentsCollectRequest: Encode<ArgumentsCollectRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsCollectRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsCollectRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsCollectRequest<'static>>, ___E> for &'a ArgumentsCollectRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsCollectRequest: Encode<ArgumentsCollectRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsCollectRequest<'static>>, ___E> for &'a ArgumentsCollectRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsCollectRequest: Encode<ArgumentsCollectRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsCollectRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsCollectRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsCollectRequest
Sourceimpl<'de> FromWire<ArgumentsCollectRequest<'de>> for ArgumentsCollectRequest
impl<'de> FromWire<ArgumentsCollectRequest<'de>> for ArgumentsCollectRequest
Sourcefn from_wire(wire: ArgumentsCollectRequest<'de>) -> Self
fn from_wire(wire: ArgumentsCollectRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsCollectRequest<'de>> for ArgumentsCollectRequest
impl<'de> FromWireRef<ArgumentsCollectRequest<'de>> for ArgumentsCollectRequest
Sourcefn from_wire_ref(wire: &ArgumentsCollectRequest<'de>) -> Self
fn from_wire_ref(wire: &ArgumentsCollectRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsCollectRequest
impl Hash for ArgumentsCollectRequest
Sourceimpl Ord for ArgumentsCollectRequest
impl Ord for ArgumentsCollectRequest
Sourcefn cmp(&self, other: &ArgumentsCollectRequest) -> Ordering
fn cmp(&self, other: &ArgumentsCollectRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsCollectRequest
impl PartialEq for ArgumentsCollectRequest
Sourcefn eq(&self, other: &ArgumentsCollectRequest) -> bool
fn eq(&self, other: &ArgumentsCollectRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsCollectRequest
impl PartialOrd for ArgumentsCollectRequest
impl StructuralPartialEq for ArgumentsCollectRequest