pub struct ArgumentsGetBoolRequest {
pub key: String,
pub defaultval: bool,
}Fields
key: Stringdefaultval: boolTrait Implementations
Sourceimpl Clone for ArgumentsGetBoolRequest
impl Clone for ArgumentsGetBoolRequest
Sourcefn clone(&self) -> ArgumentsGetBoolRequest
fn clone(&self) -> ArgumentsGetBoolRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsGetBoolRequest
impl Debug for ArgumentsGetBoolRequest
Sourceimpl<___E> Encode<ArgumentsGetBoolRequest<'static>, ___E> for ArgumentsGetBoolRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ArgumentsGetBoolRequest<'static>, ___E> for ArgumentsGetBoolRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetBoolRequest<'static>, ___E> for &'a ArgumentsGetBoolRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ArgumentsGetBoolRequest<'static>, ___E> for &'a ArgumentsGetBoolRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetBoolRequest<'static>>, ___E> for ArgumentsGetBoolRequestwhere
___E: Encoder + ?Sized,
ArgumentsGetBoolRequest: Encode<ArgumentsGetBoolRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsGetBoolRequest<'static>>, ___E> for ArgumentsGetBoolRequestwhere
___E: Encoder + ?Sized,
ArgumentsGetBoolRequest: Encode<ArgumentsGetBoolRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolRequest<'static>>, ___E> for &'a ArgumentsGetBoolRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsGetBoolRequest: Encode<ArgumentsGetBoolRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolRequest<'static>>, ___E> for &'a ArgumentsGetBoolRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsGetBoolRequest: Encode<ArgumentsGetBoolRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetBoolRequest
Sourceimpl<'de> FromWire<ArgumentsGetBoolRequest<'de>> for ArgumentsGetBoolRequest
impl<'de> FromWire<ArgumentsGetBoolRequest<'de>> for ArgumentsGetBoolRequest
Sourcefn from_wire(wire: ArgumentsGetBoolRequest<'de>) -> Self
fn from_wire(wire: ArgumentsGetBoolRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetBoolRequest<'de>> for ArgumentsGetBoolRequest
impl<'de> FromWireRef<ArgumentsGetBoolRequest<'de>> for ArgumentsGetBoolRequest
Sourcefn from_wire_ref(wire: &ArgumentsGetBoolRequest<'de>) -> Self
fn from_wire_ref(wire: &ArgumentsGetBoolRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetBoolRequest
impl Hash for ArgumentsGetBoolRequest
Sourceimpl Ord for ArgumentsGetBoolRequest
impl Ord for ArgumentsGetBoolRequest
Sourcefn cmp(&self, other: &ArgumentsGetBoolRequest) -> Ordering
fn cmp(&self, other: &ArgumentsGetBoolRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetBoolRequest
impl PartialEq for ArgumentsGetBoolRequest
Sourcefn eq(&self, other: &ArgumentsGetBoolRequest) -> bool
fn eq(&self, other: &ArgumentsGetBoolRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetBoolRequest
impl PartialOrd for ArgumentsGetBoolRequest
impl StructuralPartialEq for ArgumentsGetBoolRequest