pub struct ArgumentsGetStringsResponse {
pub values: Vec<Option<String>>,
}Fields
values: Vec<Option<String>>Trait Implementations
Sourceimpl Clone for ArgumentsGetStringsResponse
impl Clone for ArgumentsGetStringsResponse
Sourcefn clone(&self) -> ArgumentsGetStringsResponse
fn clone(&self) -> ArgumentsGetStringsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsGetStringsResponse
impl Debug for ArgumentsGetStringsResponse
Sourceimpl<___E> Encode<ArgumentsGetStringsResponse<'static>, ___E> for ArgumentsGetStringsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ArgumentsGetStringsResponse<'static>, ___E> for ArgumentsGetStringsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetStringsResponse<'static>, ___E> for &'a ArgumentsGetStringsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ArgumentsGetStringsResponse<'static>, ___E> for &'a ArgumentsGetStringsResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetStringsResponse<'static>>, ___E> for ArgumentsGetStringsResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetStringsResponse: Encode<ArgumentsGetStringsResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsGetStringsResponse<'static>>, ___E> for ArgumentsGetStringsResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetStringsResponse: Encode<ArgumentsGetStringsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringsResponse<'static>>, ___E> for &'a ArgumentsGetStringsResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringsResponse: Encode<ArgumentsGetStringsResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringsResponse<'static>>, ___E> for &'a ArgumentsGetStringsResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringsResponse: Encode<ArgumentsGetStringsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetStringsResponse
Sourceimpl<'de> FromWire<ArgumentsGetStringsResponse<'de>> for ArgumentsGetStringsResponse
impl<'de> FromWire<ArgumentsGetStringsResponse<'de>> for ArgumentsGetStringsResponse
Sourcefn from_wire(wire: ArgumentsGetStringsResponse<'de>) -> Self
fn from_wire(wire: ArgumentsGetStringsResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetStringsResponse<'de>> for ArgumentsGetStringsResponse
impl<'de> FromWireRef<ArgumentsGetStringsResponse<'de>> for ArgumentsGetStringsResponse
Sourcefn from_wire_ref(wire: &ArgumentsGetStringsResponse<'de>) -> Self
fn from_wire_ref(wire: &ArgumentsGetStringsResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetStringsResponse
impl Hash for ArgumentsGetStringsResponse
Sourceimpl Ord for ArgumentsGetStringsResponse
impl Ord for ArgumentsGetStringsResponse
Sourcefn cmp(&self, other: &ArgumentsGetStringsResponse) -> Ordering
fn cmp(&self, other: &ArgumentsGetStringsResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetStringsResponse
impl PartialEq for ArgumentsGetStringsResponse
Sourcefn eq(&self, other: &ArgumentsGetStringsResponse) -> bool
fn eq(&self, other: &ArgumentsGetStringsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetStringsResponse
impl PartialOrd for ArgumentsGetStringsResponse
impl StructuralPartialEq for ArgumentsGetStringsResponse