pub struct BoolPair {
pub key: String,
pub defaultval: bool,
}Fields
key: Stringdefaultval: boolTrait Implementations
Sourceimpl<___E> Encode<BoolPair<'static>, ___E> for BoolPairwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<BoolPair<'static>, ___E> for BoolPairwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<'a, ___E> Encode<BoolPair<'static>, ___E> for &'a BoolPairwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<BoolPair<'static>, ___E> for &'a BoolPairwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<___E> EncodeOption<Box<'static, BoolPair<'static>>, ___E> for BoolPair
impl<___E> EncodeOption<Box<'static, BoolPair<'static>>, ___E> for BoolPair
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BoolPair<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BoolPair<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BoolPair<'static>>, ___E> for &'a BoolPair
impl<'a, ___E> EncodeOption<Box<'static, BoolPair<'static>>, ___E> for &'a BoolPair
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BoolPair<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BoolPair<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for BoolPair
Sourceimpl<'de> FromWireRef<BoolPair<'de>> for BoolPair
impl<'de> FromWireRef<BoolPair<'de>> for BoolPair
Sourcefn from_wire_ref(wire: &BoolPair<'de>) -> Self
fn from_wire_ref(wire: &BoolPair<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for BoolPair
impl Ord for BoolPair
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for BoolPair
impl PartialOrd for BoolPair
impl StructuralPartialEq for BoolPair