pub struct ItemsGet2Request {
pub type_: u32,
pub extra: Option<Box<Extra>>,
}Fields
type_: u32extra: Option<Box<Extra>>Trait Implementations
Sourceimpl Clone for ItemsGet2Request
impl Clone for ItemsGet2Request
Sourcefn clone(&self) -> ItemsGet2Request
fn clone(&self) -> ItemsGet2Request
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemsGet2Request
impl Debug for ItemsGet2Request
Sourceimpl<___E> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ItemsGet2Request<'static>, ___E> for &'a ItemsGet2Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ItemsGet2Request<'static>, ___E> for &'a ItemsGet2Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ItemsGet2Request<'static>>, ___E> for ItemsGet2Request
impl<___E> EncodeOption<Box<'static, ItemsGet2Request<'static>>, ___E> for ItemsGet2Request
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ItemsGet2Request<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ItemsGet2Request<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ItemsGet2Request<'static>>, ___E> for &'a ItemsGet2Request
impl<'a, ___E> EncodeOption<Box<'static, ItemsGet2Request<'static>>, ___E> for &'a ItemsGet2Request
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ItemsGet2Request<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ItemsGet2Request<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ItemsGet2Request
Sourceimpl<'de> FromWire<ItemsGet2Request<'de>> for ItemsGet2Request
impl<'de> FromWire<ItemsGet2Request<'de>> for ItemsGet2Request
Sourcefn from_wire(wire: ItemsGet2Request<'de>) -> Self
fn from_wire(wire: ItemsGet2Request<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ItemsGet2Request<'de>> for ItemsGet2Request
impl<'de> FromWireRef<ItemsGet2Request<'de>> for ItemsGet2Request
Sourcefn from_wire_ref(wire: &ItemsGet2Request<'de>) -> Self
fn from_wire_ref(wire: &ItemsGet2Request<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ItemsGet2Request
impl Hash for ItemsGet2Request
Sourceimpl Ord for ItemsGet2Request
impl Ord for ItemsGet2Request
Sourcefn cmp(&self, other: &ItemsGet2Request) -> Ordering
fn cmp(&self, other: &ItemsGet2Request) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ItemsGet2Request
impl PartialEq for ItemsGet2Request
Sourcefn eq(&self, other: &ItemsGet2Request) -> bool
fn eq(&self, other: &ItemsGet2Request) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ItemsGet2Request
impl PartialOrd for ItemsGet2Request
impl StructuralPartialEq for ItemsGet2Request