#[repr(C)]pub struct ItemsGetRequest {
pub type_: Uint32,
pub extra: Uint32,
}Expand description
The wire type corresponding to ItemsGetRequest.
Fields
type_: Uint32extra: Uint32Trait Implementations
Sourceimpl Clone for ItemsGetRequest
impl Clone for ItemsGetRequest
Sourcefn clone(&self) -> ItemsGetRequest
fn clone(&self) -> ItemsGetRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ItemsGetRequest
impl Constrained for ItemsGetRequest
Sourceimpl Debug for ItemsGetRequest
impl Debug for ItemsGetRequest
Sourceimpl<___D> Decode<___D> for ItemsGetRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ItemsGetRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<ItemsGetRequest, ___E> for ItemsGetRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ItemsGetRequest, ___E> for ItemsGetRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<ItemsGetRequest, ___E> for &'a ItemsGetRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ItemsGetRequest, ___E> for &'a ItemsGetRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<ItemsGetRequest, ___E> for ItemsGetRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<ItemsGetRequest, ___E> for ItemsGetRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ItemsGetRequest> for ItemsGetRequest
impl FromWire<ItemsGetRequest> for ItemsGetRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ItemsGetRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ItemsGetRequest, Self>
Sourcefn from_wire(wire: ItemsGetRequest) -> Self
fn from_wire(wire: ItemsGetRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ItemsGetRequest> for ItemsGetRequest
impl FromWireRef<ItemsGetRequest> for ItemsGetRequest
Sourcefn from_wire_ref(wire: &ItemsGetRequest) -> Self
fn from_wire_ref(wire: &ItemsGetRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ItemsGetRequest
impl IntoNatural for ItemsGetRequest
Sourcetype Natural = ItemsGetRequest
type Natural = ItemsGetRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ItemsGetRequest
impl Wire for ItemsGetRequest
Sourcetype Narrowed<'de> = ItemsGetRequest
type Narrowed<'de> = ItemsGetRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.